Changelog of tags2sdists
===================================================


0.3 (2011-10-12)
----------------

- Added documentation.

- Renamed script from make_sdists to tags2sdists.


0.2 (2011-10-11)
----------------

- Added script that combines the sdist tarball creation with the target
  directory parsing and that generates all the necessary tarballs.

- Added creation (via zest.releaser) of a single sdist tarball.


0.1 (2011-10-10)
----------------

- Added parsing of a target directory with sdists.

- Initial library skeleton created by nensskel.
